@@ -65,6 +65,7 @@ class Program(object):
 
         """Initialize a new program.
 
+
         Parameters
         ----------
         name
@@ -104,8 +105,8 @@ class Program(object):
         intensity_scaler_func
             A function mapping from a week in the range [1, `duration`] to a scaling
             value (factor). The scaling value will be multiplied with the 
-            `intensity` parameter for that week. Should typically return factors
-            between 0.9 and 1.1.
+            `intensity` parameter for that week. 
+            Should typically return factors between 0.9 and 1.1.
 
         units
             The units used for exporting and printing the program, e.g. 'kg'.
@@ -151,6 +152,7 @@ class Program(object):
         >>> program = Program('My training program')
         >>> program._rendered
         False
+
         """
         self.name = escape_string(name)
 
